package
Version:
v0.0.31
Opens a new window with list of versions in this module.
Published: Aug 3, 2026
License: BSD-3-Clause
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Rect:UI 通用几何类型(int 像素),UIKit 风格用它拼 UI。
不依赖任何 UI 包,所有控件都能用。
func NewRect(x, y, width, height int) Rect
New:便捷构造(类似 CGRectMake)
Source Files
¶
Click to show internal directories.
Click to hide internal directories.