package
Version:
v0.0.35
Opens a new window with list of versions in this module.
Published: Aug 5, 2026
License: BSD-3-Clause
Opens a new window with license information.
Imports: 6
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
NewUIModal 创建一个嵌入自定义 UIView 的模态对话框
func (a *UIAlert) OnCancel(cb func())
func (a *UIAlert) OnConfirm(cb func())
Source Files
¶
Click to show internal directories.
Click to hide internal directories.