slider

package
v0.0.39 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 7, 2026 License: BSD-3-Clause Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type SliderStyle

type SliderStyle struct {
	Type           fltk_bridge.SliderType
	BoxType        fltk_bridge.BoxType
	Color          uint
	SelectionColor uint
	TextSize       int
}

func DefaultSliderStyle

func DefaultSliderStyle() SliderStyle

type UISlider

type UISlider struct {
	// contains filtered or unexported fields
}

func NewUISlider

func NewUISlider(r *foundation.Rect) *UISlider

func NewUISliderWithOptions

func NewUISliderWithOptions(r *foundation.Rect, style SliderStyle) *UISlider

func (*UISlider) ApplyStyle

func (s *UISlider) ApplyStyle(style SliderStyle)

func (*UISlider) OnChange

func (s *UISlider) OnChange(cb func())

OnChange is a convenience variant for callers that do not need the value.

func (*UISlider) OnValueChanged

func (s *UISlider) OnValueChanged(cb func(float64))

OnValueChanged invokes cb with the current slider value whenever FLTK reports a value-change event.

func (*UISlider) Raw

func (s *UISlider) Raw() *fltk_bridge.Slider

func (*UISlider) SetMaximum

func (s *UISlider) SetMaximum(v float64)

func (*UISlider) SetMaximumValue

func (s *UISlider) SetMaximumValue(v float64)

func (*UISlider) SetMinimum

func (s *UISlider) SetMinimum(v float64)

func (*UISlider) SetMinimumValue

func (s *UISlider) SetMinimumValue(v float64)

func (*UISlider) SetStep

func (s *UISlider) SetStep(v float64)

func (*UISlider) SetType

func (s *UISlider) SetType(t fltk_bridge.SliderType)

func (*UISlider) SetValue

func (s *UISlider) SetValue(v float64)

func (*UISlider) SetVertical

func (s *UISlider) SetVertical(vertical bool)

func (*UISlider) Style

func (s *UISlider) Style() SliderStyle

func (*UISlider) Value

func (s *UISlider) Value() float64

func (*UISlider) View

func (s *UISlider) View() *view.UIView

Jump to