Documentation
¶
Index ¶
- type KeyEvent
- type UITextView
- func (t *UITextView) Append(text string)
- func (t *UITextView) AppendAndScroll(text string)
- func (t *UITextView) AppendText(text string)
- func (t *UITextView) On(event fltk_bridge.Event, handler func(fltk_bridge.Event) bool)
- func (t *UITextView) OnKey(cb func(KeyEvent) bool)
- func (t *UITextView) OnTextChanged(cb func())
- func (t *UITextView) Raw() *fltk_bridge.TextEditor
- func (t *UITextView) ScrollToEnd()
- func (t *UITextView) SetAutomationID(id string) *UITextView
- func (t *UITextView) SetAutomationName(name string) *UITextView
- func (t *UITextView) SetBackgroundColor(rgb uint)
- func (t *UITextView) SetFallbackFont(font fltk_bridge.Font, match func(rune) bool)
- func (t *UITextView) SetFont(font fltk_bridge.Font)
- func (t *UITextView) SetFontSize(size int)
- func (t *UITextView) SetTabWidth(width int)
- func (t *UITextView) SetText(text string)
- func (t *UITextView) SetTextColor(rgb uint)
- func (t *UITextView) SetWrapAtBounds()
- func (t *UITextView) SetWrapNone()
- func (t *UITextView) Text() string
- func (t *UITextView) TextBuffer() *fltk_bridge.TextBuffer
- func (t *UITextView) View() *view.UIView
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type UITextView ¶
type UITextView struct {
// contains filtered or unexported fields
}
func NewUITextView ¶
func NewUITextView(r *foundation.Rect) *UITextView
func (*UITextView) Append ¶
func (t *UITextView) Append(text string)
func (*UITextView) AppendAndScroll ¶
func (t *UITextView) AppendAndScroll(text string)
func (*UITextView) AppendText ¶
func (t *UITextView) AppendText(text string)
func (*UITextView) On ¶
func (t *UITextView) On(event fltk_bridge.Event, handler func(fltk_bridge.Event) bool)
func (*UITextView) OnKey ¶
func (t *UITextView) OnKey(cb func(KeyEvent) bool)
func (*UITextView) OnTextChanged ¶
func (t *UITextView) OnTextChanged(cb func())
func (*UITextView) Raw ¶
func (t *UITextView) Raw() *fltk_bridge.TextEditor
func (*UITextView) ScrollToEnd ¶
func (t *UITextView) ScrollToEnd()
func (*UITextView) SetAutomationID ¶
func (t *UITextView) SetAutomationID(id string) *UITextView
func (*UITextView) SetAutomationName ¶
func (t *UITextView) SetAutomationName(name string) *UITextView
func (*UITextView) SetBackgroundColor ¶
func (t *UITextView) SetBackgroundColor(rgb uint)
func (*UITextView) SetFallbackFont ¶ added in v0.0.24
func (t *UITextView) SetFallbackFont(font fltk_bridge.Font, match func(rune) bool)
SetFallbackFont styles matching Unicode runes with a second FLTK font while preserving the primary font for all other text. It is intended for native font stacks where one platform font cannot cover every required script (for example, a CJK font plus an emoji font). Configure the primary font, size and color before calling this method.
func (*UITextView) SetFont ¶
func (t *UITextView) SetFont(font fltk_bridge.Font)
func (*UITextView) SetFontSize ¶
func (t *UITextView) SetFontSize(size int)
func (*UITextView) SetTabWidth ¶
func (t *UITextView) SetTabWidth(width int)
func (*UITextView) SetText ¶
func (t *UITextView) SetText(text string)
func (*UITextView) SetTextColor ¶
func (t *UITextView) SetTextColor(rgb uint)
func (*UITextView) SetWrapAtBounds ¶
func (t *UITextView) SetWrapAtBounds()
func (*UITextView) SetWrapNone ¶
func (t *UITextView) SetWrapNone()
func (*UITextView) Text ¶
func (t *UITextView) Text() string
func (*UITextView) TextBuffer ¶
func (t *UITextView) TextBuffer() *fltk_bridge.TextBuffer
func (*UITextView) View ¶
func (t *UITextView) View() *view.UIView
Click to show internal directories.
Click to hide internal directories.