Documentation
¶
Index ¶
- type SliderStyle
- type UISlider
- func (s *UISlider) ApplyStyle(style SliderStyle)
- func (s *UISlider) OnChange(cb func())
- func (s *UISlider) OnValueChanged(cb func(float64))
- func (s *UISlider) Raw() *fltk_bridge.Slider
- func (s *UISlider) SetMaximum(v float64)
- func (s *UISlider) SetMaximumValue(v float64)
- func (s *UISlider) SetMinimum(v float64)
- func (s *UISlider) SetMinimumValue(v float64)
- func (s *UISlider) SetStep(v float64)
- func (s *UISlider) SetType(t fltk_bridge.SliderType)
- func (s *UISlider) SetValue(v float64)
- func (s *UISlider) SetVertical(vertical bool)
- func (s *UISlider) Style() SliderStyle
- func (s *UISlider) Value() float64
- func (s *UISlider) View() *view.UIView
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type SliderStyle ¶
type SliderStyle struct {
Type fltk_bridge.SliderType
BoxType fltk_bridge.BoxType
Color uint
SelectionColor uint
TextSize int
}
func DefaultSliderStyle ¶
func DefaultSliderStyle() SliderStyle
type UISlider ¶
type UISlider struct {
// contains filtered or unexported fields
}
func NewUISlider ¶
func NewUISlider(r *foundation.Rect) *UISlider
func NewUISliderWithOptions ¶
func NewUISliderWithOptions(r *foundation.Rect, style SliderStyle) *UISlider
func (*UISlider) ApplyStyle ¶
func (s *UISlider) ApplyStyle(style SliderStyle)
func (*UISlider) OnChange ¶
func (s *UISlider) OnChange(cb func())
OnChange is a convenience variant for callers that do not need the value.
func (*UISlider) OnValueChanged ¶
OnValueChanged invokes cb with the current slider value whenever FLTK reports a value-change event.
func (*UISlider) Raw ¶
func (s *UISlider) Raw() *fltk_bridge.Slider
func (*UISlider) SetMaximum ¶
func (*UISlider) SetMaximumValue ¶
func (*UISlider) SetMinimum ¶
func (*UISlider) SetMinimumValue ¶
func (*UISlider) SetType ¶
func (s *UISlider) SetType(t fltk_bridge.SliderType)
func (*UISlider) SetVertical ¶
func (*UISlider) Style ¶
func (s *UISlider) Style() SliderStyle
Click to show internal directories.
Click to hide internal directories.