package
Version:
v0.0.23
Opens a new window with list of versions in this module.
Published: Jul 31, 2026
License: BSD-3-Clause
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type UITabView struct {
}
UITabView 封装基于现代 UI 理念的分段控制器/多标签视图
NewUITabView 创建一个新的分段标签容器
Source Files
¶
Click to show internal directories.
Click to hide internal directories.